@testset "8 plots" begin
    f = Figure(resolution=(1200, 1400))
    ga = f[1, 1]
    gc = f[2, 1]
    ge = f[3, 1]
    gg = f[4, 1]
    gb = f[1, 2]
    gd = f[2, 2]
    gf = f[3, 2]
    gh = f[4, 2]

    include("../docs/example_data.jl")
    d_topo, pos = example_data("TopoPlots.jl")
    uf_deconv = example_data("UnfoldLinearModelContinuousTime")
    uf = example_data("UnfoldLinearModel")
    results = coeftable(uf)
    uf_5chan = example_data("UnfoldLinearModelMultiChannel")
    d_singletrial, _ = UnfoldSim.predef_eeg(; return_epoched=true)
    times = -0.099609375:0.001953125:1.0
    data, positions = TopoPlots.example_data()
    df = UnfoldMakie.eeg_matrix_to_dataframe(data[:,:,1], string.(1:length(positions)));
    raw_ch_names = ["FP1", "F3", "F7", "FC3", "C3", "C5", "P3", "P7", "P9", "PO7", 
"PO3", "O1", "Oz", "Pz", "CPz", "FP2", "Fz", "F4", "F8", "FC4", "FCz", "Cz", 
"C4", "C6", "P4", "P8", "P10", "PO8", "PO4", "O2"]

    data_erp, evts = UnfoldSim.predef_eeg(; noiselevel = 12, return_epoched = true)
    data_erp = reshape(data_erp, (1, size(data_erp)...))
    form = @formula 0 ~ 1 + condition + continuous
    se_solver = (x, y) -> Unfold.solver_default(x, y, stderror = true);
    m = fit(
        UnfoldModel,
        Dict(Any => (form, range(0, step = 1 / 100, length = size(data_erp, 2)))),
        evts,
        data_erp,
        solver = se_solver,
    )
    results = coeftable(m)
    res_effects = effects(Dict(:continuous => -5:0.5:5), m);

    plot_erp!(ga, results; :stderror=>true, legend=(; framevisible = false))
    plot_butterfly!(gb, d_topo; positions=pos, topomarkersize = 10, topoheigth = 0.4, topowidth = 0.4,)
    plot_topoplot!(gc, data[:,340,1]; positions = positions)
    plot_topoplotseries!(gd, df, 80; positions=positions, visual=(label_scatter=false,), 
        layout = (; use_colorbar=true))
    plot_erpgrid!(ge, data[:, :, 1], positions)





    dat, evts =
        UnfoldSim.predef_eeg(; onset = LogNormalOnset(μ = 3.5, σ = 0.4), noiselevel = 5)
    dat_e, times = Unfold.epoch(dat, evts, [-0.1, 1], 100)
    evts, dat_e = Unfold.dropMissingEpochs(evts, dat_e)
    evts.Δlatency =  diff(vcat(evts.latency, 0)) *-1
    dat_e = dat_e[1,:,:]
    plot_erpimage!(gf, times, dat_e; sortvalues=evts.Δlatency)
    plot_channelimage!(gg, data[:, :, 1], positions[1:30], raw_ch_names; )
     plot_parallelcoordinates(gh, uf_5chan; 
        mapping=(; color=:coefname), 
        layout=(; legend_position=:right))


    for (label, layout) in zip(["A", "B", "C", "D", "E", "F", "G", "H"], [ga, gb, gc, gd, ge, gf, gg, gh])
        Label(layout[1, 1, TopLeft()], label,
            fontsize=26,
            font=:bold,
            padding=(0, 5, 5, 0),
            halign=:right)
    end
    f
end

@testset "8 plots with a Figure" begin
    f = Figure(resolution=(1200, 1400))

    include("../docs/example_data.jl")
    d_topo, positions = example_data("TopoPlots.jl")
    data, positions = TopoPlots.example_data()
    uf = example_data("UnfoldLinearModel")
    results = coeftable(uf)
    uf_5chan = example_data("UnfoldLinearModelMultiChannel")
    d_singletrial, _ = UnfoldSim.predef_eeg(; return_epoched=true)


    pvals = DataFrame(
        from=[0.1, 0.15],
        to=[0.2, 0.5],
        # if coefname not specified, line should be black
        coefname=["(Intercept)", "category: face"]
    )
     plot_erp!(f[1, 1], results, extra=(;
        categoricalColor=false,
        categoricalGroup=false,
        pvalue=pvals,
        stderror=true)) 

    plot_butterfly!(f[1, 2], d_topo; positions=positions)
    plot_topoplot!(f[2, 1], data[:, 150, 1]; positions=positions)
    plot_topoplotseries!(f[2, 2], d_topo, 0.1; positions=positions, visual=(label_scatter=false,), layout = (; use_colorbar=true))
    plot_erpgrid!(f[3, 1], data[:, :, 1], positions)
   
    times = -0.099609375:0.001953125:1.0
    plot_erpimage!(f[3, 2], times, d_singletrial)

    plot_parallelcoordinates(
        f[4, 2],
        uf_5chan;
        mapping = (; color = :coefname),
        layout = (; legend_position = :right),
    )

    for (label, layout) in zip(["A", "B", "C", "D", "E", "F", "G", "H"], 
        [f[1, 1], f[1, 2], f[2, 1], f[2, 2], f[3, 1], f[3, 2], f[4, 1], f[4, 2]])
        Label(layout[1, 1, TopLeft()], label,
            fontsize=26,
            font=:bold,
            padding=(0, 5, 5, 0),
            halign=:right)
    end
    f
end


@testset "testing combined figure (a Figure from mult_viz_in_fig from docs)" begin
    include("../docs/example_data.jl")
    d_topo, positions = example_data("TopoPlots.jl")
    uf_deconv = example_data("UnfoldLinearModelContinuousTime")
    uf = example_data("UnfoldLinearModel")
    results = coeftable(uf)
    uf_5chan = example_data("UnfoldLinearModelMultiChannel")
    d_singletrial, _ = UnfoldSim.predef_eeg(; return_epoched=true)
    data, positions = TopoPlots.example_data()
    times = -0.099609375:0.001953125:1.0

    f = Figure(resolution=(2000, 2000))

    plot_butterfly!(f[1, 1:3], d_topo; positions=positions)

    pvals = DataFrame(
        from=[0.1, 0.15],
        to=[0.2, 0.5],
        # if coefname not specified, line should be black
        coefname=["(Intercept)", "category: face"]
    )
    plot_erp!(f[2, 1:2], results, 
        categorical_color=false,
        categorical_group=false,
        pvalue=pvals,
        stderror=true)
    
    plot_designmatrix!(f[2, 3], designmatrix(uf))
    
    plot_topoplot!(f[3, 1], data[:, 150, 1]; positions=positions)
    plot_topoplotseries!(f[4, 1:3], d_topo, 0.1; positions=positions, mapping=(; label=:channel))
    
    res_effects = effects(Dict(:continuous => -5:0.5:5), uf_deconv)
    
    plot_erp!(f[2, 4:5], res_effects; categorical_color=false, categorical_group=true,
        mapping=(; y=:yhat, color=:continuous, group=:continuous),
        legend=(; nbanks=2),
        layout=(; show_legend=true, legend_position=:right))
    
    plot_parallelcoordinates(f[3, 2:3], uf_5chan; mapping=(; color=:coefname), layout=(; legend_position=:right))
    
    plot_erpimage!(f[1, 4:5], times, d_singletrial)
    plot_circulareegtopoplot!(f[3:4, 4:5], d_topo[in.(d_topo.time, Ref(-0.3:0.1:0.5)), :];
        positions=positions, predictor=:time, predictor_bounds=[-0.3, 0.5])
    
    f
    #save("test.png", f)
end